@@ -1,6 +1,5 @@
 #!/bin/bash
-# root=overlay:UUID=uuid was converted to
-# root=block:/dev/disk/by-uuid/uuid in cmdline hook
+# root=overlay:* was converted into a root=block:/dev/... node
 type getOverlayBaseDirectory >/dev/null 2>&1 || . /lib/kiwi-filesystem-lib.sh
 
 #======================================
@@ -21,18 +20,34 @@ function loadKernelModules {
 }
 
 function initGlobalDevices {
+    local nbd_host
+    local nbd_export
     if [ -z "$1" ]; then
         die "No root device for operation given"
     fi
-    write_partition="$1"
-    root_disk=$(
-        lsblk -p -n -r -s -o NAME,TYPE "${write_partition}" |\
-        grep disk | cut -f1 -d ' '
-    )
-    read_only_partition=$(
-        lsblk -p -r --fs -o NAME,FSTYPE "${root_disk}" |\
-        grep squashfs | cut -f1 -d ' '
-    )
+    write_partition=$(getarg rd.root.overlay.write=)
+    if [[ "${root_cmdline}" =~ "overlay:nbd=" ]];then
+        nbd_host=$(echo "${root_cmdline}" | cut -f2 -d= | cut -f1 -d:)
+        nbd_export=$(echo "${root_cmdline}" | cut -f3 -d:)
+        read_only_partition="/dev/nbd0"
+        if ! nbd-client \
+            "${nbd_host}" "${read_only_partition}" -name "${nbd_export}"
+        then
+            die "Failed to setup nbd client for ${root_cmdline}"
+        fi
+    elif [[ "${root_cmdline}" =~ "overlay:aoe=" ]];then
+        read_only_partition="/dev/etherd/$(echo "${root_cmdline}"|cut -f2 -d=)"
+    else
+        write_partition="$1"
+        root_disk=$(
+            lsblk -p -n -r -s -o NAME,TYPE "${write_partition}" |\
+            grep disk | cut -f1 -d ' '
+        )
+        read_only_partition=$(
+            lsblk -p -r --fs -o NAME,FSTYPE "${root_disk}" |\
+            grep squashfs | cut -f1 -d ' '
+        )
+    fi
 }
 
 function mountReadOnlyRootImage {
@@ -71,6 +86,14 @@ function preparePersistentOverlay {
 PATH=/usr/sbin:/usr/bin:/sbin:/bin
 
 declare root=${root}
+declare root_cmdline
+
+root_cmdline=$(getarg root=)
+
+# only run if overlay is requested
+if [[ ! "${root_cmdline}" =~ "overlay:" ]];then
+    return 0
+fi
 
 # init debug log file if wanted
 setupDebugMode
@@ -85,7 +108,7 @@ loadKernelModules
 mountReadOnlyRootImage
 
 # prepare overlay for generated systemd OverlayOS_rootfs service
-if getargbool 0 rd.root.overlay.readonly; then
+if [ -z "${write_partition}" ] || getargbool 0 rd.root.overlay.readonly; then
     prepareTemporaryOverlay
 else
     preparePersistentOverlay
