@@ -314,7 +314,10 @@ class Defaults:
 
         :rtype: list
         """
-        return ['-a', '-H', '-X', '-A', '--one-file-system', '--inplace']
+        return [
+            '--archive', '--hard-links', '--xattrs', '--acls',
+            '--one-file-system', '--inplace'
+        ]
 
     @staticmethod
     def get_exclude_list_for_root_data_sync():
@@ -470,15 +473,26 @@ class Defaults:
         return 'INSTALL'
 
     @staticmethod
-    def get_snapper_config_template_file():
+    def get_snapper_config_template_file(root: str) -> str:
         """
-        Provides the default configuration template file for snapper
+        Provides the default configuration template file for snapper.
+        The location in etc/ are preferred over files in usr/
 
-        :return: file
+        :return: file path
 
         :rtype: str
         """
-        return '/etc/snapper/config-templates/default'
+        snapper_templates = [
+            'etc/snapper/config-templates/default',
+            'usr/share/snapper/config-templates/default'
+        ]
+        snapper_default_conf = ''
+        for snapper_template in snapper_templates:
+            template_config = os.path.join(root, snapper_template)
+            if os.path.exists(template_config):
+                snapper_default_conf = template_config
+                break
+        return snapper_default_conf
 
     @staticmethod
     def get_default_video_mode():
@@ -1156,6 +1170,7 @@ class Defaults:
             'armv6l': ['efi', 'uefi'],
             'armv7hl': ['efi', 'uefi'],
             'armv7l': ['efi', 'uefi'],
+            'armv8l': ['efi', 'uefi'],
             'ppc': ['ofw'],
             'ppc64': ['ofw', 'opal'],
             'ppc64le': ['ofw', 'opal'],
@@ -1184,12 +1199,14 @@ class Defaults:
             'ppc64': 'ofw',
             'ppc64le': 'ofw',
             'arm64': 'efi',
+            'aarch64': 'efi',
             'armv5el': 'efi',
             'armv5tel': 'efi',
             'armv6hl': 'efi',
             'armv6l': 'efi',
             'armv7hl': 'efi',
             'armv7l': 'efi',
+            'armv8l': 'efi',
             'riscv64': 'efi'
         }
         if arch in default_firmware:
@@ -1247,6 +1264,7 @@ class Defaults:
             'armv5tel': 'arm-efi',
             'armv6l': 'arm-efi',
             'armv7l': 'arm-efi',
+            'armv8l': 'arm-efi',
             'riscv64': 'riscv64-efi'
         }
         if arch in default_module_directory_names:
@@ -1282,6 +1300,7 @@ class Defaults:
             'armv5tel': 'bootarm.efi',
             'armv6l': 'bootarm.efi',
             'armv7l': 'bootarm.efi',
+            'armv8l': 'bootarm.efi',
             'riscv64': 'bootriscv64.efi'
         }
         if arch in default_efi_image_names:
@@ -1621,13 +1640,13 @@ class Defaults:
     @staticmethod
     def get_container_compression():
         """
-        Provides default container compression algorithm
+        Provides default container compression
 
-        :return: name
+        :return: True
 
-        :rtype: str
+        :rtype: bool
         """
-        return 'xz'
+        return True
 
     @staticmethod
     def get_default_container_name():
