@@ -15,12 +15,17 @@
 # You should have received a copy of the GNU General Public License
 # along with kiwi.  If not, see <http://www.gnu.org/licenses/>
 #
+import os
 import time
 import logging
+from textwrap import dedent
+from typing import List
 
 # project
+from kiwi.path import Path
 from kiwi.utils.temporary import Temporary
 from kiwi.command import Command
+from kiwi.exceptions import KiwiUmountBusyError
 
 log = logging.getLogger('kiwi')
 
@@ -37,7 +42,7 @@ class MountManager:
     * :param string device: device node name
     * :param string mountpoint: mountpoint directory name
     """
-    def __init__(self, device, mountpoint=None):
+    def __init__(self, device: str, mountpoint: str = ''):
         self.device = device
         if not mountpoint:
             self.mountpoint_tempdir = Temporary(
@@ -47,7 +52,7 @@ class MountManager:
         else:
             self.mountpoint = mountpoint
 
-    def bind_mount(self):
+    def bind_mount(self) -> None:
         """
         Bind mount the device to the mountpoint
         """
@@ -56,7 +61,7 @@ class MountManager:
                 ['mount', '-n', '--bind', self.device, self.mountpoint]
             )
 
-    def mount(self, options=None):
+    def mount(self, options: List[str] = []) -> None:
         """
         Standard mount the device to the mountpoint
 
@@ -70,7 +75,7 @@ class MountManager:
                 ['mount'] + option_list + [self.device, self.mountpoint]
             )
 
-    def umount_lazy(self):
+    def umount_lazy(self) -> None:
         """
         Umount by the mountpoint directory in lazy mode
 
@@ -81,11 +86,15 @@ class MountManager:
         if self.is_mounted():
             Command.run(['umount', '-l', self.mountpoint])
 
-    def umount(self):
+    def umount(self, raise_on_busy: bool = True) -> bool:
         """
         Umount by the mountpoint directory
 
-        If the resource is busy the call will return False
+        Wait up to 10sec trying to umount. If the resource stays
+        busy the call will raise an exception unless raise_on_busy
+        is set to False. In case the umount failed and raise_on_busy
+        is set to False, the method returns False to indicate the
+        error condition.
 
         :return: True or False
 
@@ -93,7 +102,7 @@ class MountManager:
         """
         if self.is_mounted():
             umounted_successfully = False
-            for busy in [1, 2, 3]:
+            for busy in range(0, 10):
                 try:
                     Command.run(['umount', self.mountpoint])
                     umounted_successfully = True
@@ -105,15 +114,47 @@ class MountManager:
                     )
                     time.sleep(1)
             if not umounted_successfully:
-                log.warning(
-                    '%s still busy at %s', self.mountpoint, type(self).__name__
-                )
-                # skip removing the mountpoint directory
-                return False
+                if raise_on_busy:
+                    lsof = Path.which('lsof', access_mode=os.X_OK)
+                    if lsof:
+                        open_files = Command.run(
+                            [lsof, '+c', '0', self.mountpoint],
+                            raise_on_error=False
+                        )
+                        open_files_info = 'Open files status:{0}{1}'.format(
+                            os.linesep, open_files.output
+                        )
+                    else:
+                        open_files_info = 'For further details install: lsof'
+                    message = dedent('''\n
+                        Failed to umount: {0}.
 
+                        Your build host system is in an inconsistent state.
+                        The cleanup of the created resource was not possible
+                        because it is still busy. This resource and all nested
+                        resources stays active on your host and needs a manual
+                        cleanup.
+
+                        Please do not use the intermediate state of the image
+                        files created so far. There is no guarantee that the
+                        produced results are valid.
+
+                        {1}
+                    ''')
+                    raise KiwiUmountBusyError(
+                        message.format(self.mountpoint, open_files_info)
+                    )
+                else:
+                    log.warning(
+                        '{0} still busy at {1}'.format(
+                            self.mountpoint, type(self).__name__
+                        )
+                    )
+                    # skip removing the mountpoint directory
+                    return False
         return True
 
-    def is_mounted(self):
+    def is_mounted(self) -> bool:
         """
         Check if mounted
 
