@@ -17,8 +17,11 @@
 #
 import re
 import os
+import glob
 import logging
-from typing import List
+from typing import (
+    List, Dict
+)
 
 # project
 from kiwi.command import command_call_type
@@ -109,6 +112,17 @@ class PackageManagerApt(PackageManagerBase):
             'Package exclusion for (%s) not supported for apt-get', name
         )
 
+    def setup_repository_modules(
+        self, collection_modules: Dict[str, List[str]]
+    ) -> None:
+        """
+        Repository modules not supported for apt-get
+        The method does nothing in this scope
+
+        :param dict collection_modules: unused
+        """
+        pass
+
     def process_install_requests_bootstrap(
         self, root_bind: RootBind = None
     ) -> command_call_type:
@@ -257,9 +271,53 @@ class PackageManagerApt(PackageManagerBase):
                 'None of the requested packages to delete are installed'
             )
 
+        # deleting debs for some reason can also trigger package
+        # scripts from the libc-bin (glibc) package. This often
+        # results in calls like ldconfig which failed unless the
+        # system would be really running. Since the deletion
+        # happens via chroot and with the system in offline mode
+        # many attempts to uninstall a package, even cracefully
+        # failed for this reason. So far I only saw the workaround
+        # to make ldconfig a noop during the process of uninstall.
+        # This is not a nice solution and I dislike it. However,
+        # the only one I could come up with to turn the package
+        # uninstall in a useful feature in kiwi.
+        Command.run(
+            [
+                'cp',
+                f'{self.root_dir}/usr/sbin/ldconfig',
+                f'{self.root_dir}/usr/sbin/ldconfig.orig'
+            ]
+        )
+        Command.run(
+            [
+                'cp',
+                f'{self.root_dir}/usr/bin/true',
+                f'{self.root_dir}/usr/sbin/ldconfig'
+            ]
+        )
         if force:
+            # force deleting debs only worked well for me when ignoring
+            # the pre-inst and pre-remove codings. I don't know why this
+            # ends in so many conflicts but if you want to force get rid
+            # of stuff this was the only way I could come up with. There
+            # are still cases when it does not work depending on the many
+            # code that runs on deleting
+            for package in delete_items:
+                delete_pattern = \
+                    f'{self.root_dir}/var/lib/dpkg/info/{package}*.pre*'
+                for delete_file in glob.iglob(delete_pattern):
+                    Path.wipe(delete_file)
+
             apt_get_command = ['chroot', self.root_dir, 'dpkg']
-            apt_get_command.extend(['--force-all', '-r'])
+            apt_get_command.extend(
+                [
+                    '--remove',
+                    '--force-remove-reinstreq',
+                    '--force-remove-essential',
+                    '--force-depends'
+                ]
+            )
             apt_get_command.extend(delete_items)
         else:
             apt_get_command = ['chroot', self.root_dir, 'apt-get']
@@ -274,6 +332,22 @@ class PackageManagerApt(PackageManagerBase):
             apt_get_command, self.command_env
         )
 
+    def post_process_delete_requests(
+        self, root_bind: RootBind = None
+    ) -> None:
+        """
+        Revert system changes done prior deleting packages
+
+        :param object root_bind: unused
+        """
+        Command.run(
+            [
+                'mv',
+                f'{self.root_dir}/usr/sbin/ldconfig.orig',
+                f'{self.root_dir}/usr/sbin/ldconfig'
+            ]
+        )
+
     def update(self) -> command_call_type:
         """
         Process package update requests (chroot)
