@@ -60,7 +60,10 @@ class TestFileSystemBase:
         mock_sync.assert_called_once_with('root_dir', 'tmpdir')
         data_sync.sync_data.assert_called_once_with(
             exclude=['exclude_me'],
-            options=['-a', '-H', '-X', '-A', '--one-file-system', '--inplace']
+            options=[
+                '--archive', '--hard-links', '--xattrs',
+                '--acls', '--one-file-system', '--inplace'
+            ]
         )
         mock_mount.assert_called_once_with(
             device='/dev/loop0'
