@@ -7,7 +7,7 @@ from kiwi.filesystem.clicfs import FileSystemClicFs
 
 class TestFileSystemClicFs:
     @patch('os.path.exists')
-    def setup(self, mock_exists):
+    def setup(self, mock_FileSystemClicFs, mock_exists):
         mock_exists.return_value = True
         self.clicfs = FileSystemClicFs(mock.Mock(), 'root_dir')
 
