@@ -1,4 +1,6 @@
-from mock import patch
+from mock import (
+    patch, call
+)
 from pytest import raises
 import mock
 
@@ -42,6 +44,49 @@ class TestPackageManagerMicroDnf:
         self.manager.request_package_exclusion('name')
         assert self.manager.exclude_requests == ['name']
 
+    @patch('kiwi.command.Command.run')
+    def test_setup_repository_modules(self, mock_run):
+        self.manager.setup_repository_modules(
+            {
+                'disable': ['mod_c'],
+                'enable': ['mod_a:stream', 'mod_b']
+            }
+        )
+        microdnf_call_args = [
+            'microdnf', '--refresh', '--config', '/root-dir/dnf.conf',
+            '-y', '--installroot', '/root-dir', '--releasever=0',
+            '--noplugins', '--setopt=cachedir=cache',
+            '--setopt=reposdir=repos',
+            '--setopt=varsdir=vars'
+        ]
+        assert mock_run.call_args_list == [
+            call(
+                microdnf_call_args + [
+                    'module', 'disable', 'mod_c'
+                ], ['env']
+            ),
+            call(
+                microdnf_call_args + [
+                    'module', 'reset', 'mod_a'
+                ], ['env']
+            ),
+            call(
+                microdnf_call_args + [
+                    'module', 'enable', 'mod_a:stream'
+                ], ['env']
+            ),
+            call(
+                microdnf_call_args + [
+                    'module', 'reset', 'mod_b'
+                ], ['env']
+            ),
+            call(
+                microdnf_call_args + [
+                    'module', 'enable', 'mod_b'
+                ], ['env']
+            )
+        ]
+
     @patch('kiwi.command.Command.call')
     @patch('kiwi.command.Command.run')
     def test_process_install_requests_bootstrap(self, mock_run, mock_call):
@@ -68,7 +113,7 @@ class TestPackageManagerMicroDnf:
         mock_call.assert_called_once_with(
             [
                 'chroot', '/root-dir', 'microdnf', '--config', '/dnf.conf',
-                '-y', '--exclude=skipme', 'install', 'vim'
+                '-y', '--releasever=0', '--exclude=skipme', 'install', 'vim'
             ], ['env']
         )
 
@@ -95,7 +140,8 @@ class TestPackageManagerMicroDnf:
         mock_call.assert_called_once_with(
             [
                 'chroot', '/root-dir', 'microdnf',
-                '--config', '/dnf.conf', '-y', 'remove', 'vim'
+                '--config', '/dnf.conf', '-y',
+                '--releasever=0', 'remove', 'vim'
             ],
             ['env']
         )
@@ -119,7 +165,7 @@ class TestPackageManagerMicroDnf:
         mock_call.assert_called_once_with(
             [
                 'chroot', '/root-dir', 'microdnf',
-                '--config', '/dnf.conf', '-y', 'upgrade'
+                '--config', '/dnf.conf', '-y', '--releasever=0', 'upgrade'
             ], ['env']
         )
 
