@@ -30,7 +30,10 @@ class TestSystemPrepare:
     @patch('kiwi.system.prepare.RootInit')
     @patch('kiwi.system.prepare.RootBind')
     @patch('kiwi.logger.Logger.get_logfile')
-    def setup(self, mock_get_logfile, mock_root_bind, mock_root_init):
+    def setup(
+        self, mock_SystemPrepare, mock_get_logfile,
+        mock_root_bind, mock_root_init
+    ):
         Defaults.set_platform_name('x86_64')
         mock_get_logfile.return_value = None
         description = XMLDescription(
@@ -293,6 +296,9 @@ class TestSystemPrepare:
         self.manager.request_product.assert_called_once_with(
             'kiwi'
         )
+        self.manager.setup_repository_modules.assert_called_once_with(
+            {'disable': ['mod_c'], 'enable': ['mod_a:stream', 'mod_b']}
+        )
         self.manager.process_install_requests_bootstrap.assert_called_once_with(
             self.system.root_bind
         )
@@ -400,6 +406,9 @@ class TestSystemPrepare:
         self.manager.process_delete_requests.assert_has_calls(
             [call(False), call(True)]
         )
+        self.manager.post_process_delete_requests.assert_has_calls(
+            [call(self.system.root_bind), call(self.system.root_bind)]
+        )
 
     @patch('kiwi.system.prepare.CommandProcess.poll_show_progress')
     def test_pinch_system_raises(self, mock_poll):
