@@ -206,6 +206,46 @@ class TestResultBundleTask:
             os.sep.join([self.abs_bundle_dir, 'test-image-1.2.3-Build_42'])
         )
 
+    @patch('kiwi.tasks.result_bundle.Result.load')
+    @patch('kiwi.tasks.result_bundle.Command.run')
+    @patch('kiwi.tasks.result_bundle.Path.create')
+    @patch('os.path.exists')
+    def test_process_result_bundle_with_bundle_format(
+        self, mock_exists, mock_path_create, mock_command, mock_load
+    ):
+        self.xml_state.profiles = None
+        self.xml_state.host_architecture = 'x86_64'
+        self.xml_state.get_build_type_name = Mock(
+            return_value='oem'
+        )
+        self.xml_state.xml_data.get_name = Mock(
+            return_value='Leap-15.2'
+        )
+
+        result = Result(self.xml_state)
+        result.add_bundle_format('%N-%T:%M')
+        result.add(
+            key='disk_image',
+            filename='/tmp/mytest/Leap-15.2.x86_64-1.15.2.raw',
+            use_for_bundle=True, compress=False, shasum=False
+        )
+
+        mock_exists.return_value = False
+        mock_load.return_value = result
+        self._init_command_args()
+
+        self.task.process()
+
+        mock_command.assert_called_once_with(
+            [
+                'cp',
+                '/tmp/mytest/Leap-15.2.x86_64-1.15.2.raw',
+                os.sep.join(
+                    [self.abs_bundle_dir, 'Leap-15.2-oem:1.raw']
+                )
+            ]
+        )
+
     @patch('kiwi.tasks.result_bundle.Result.load')
     @patch('kiwi.tasks.result_bundle.Command.run')
     @patch('kiwi.tasks.result_bundle.Path.create')
