@@ -26,12 +26,15 @@ class TestDataSync:
         mock_xattr_support.return_value = False
         with self._caplog.at_level(logging.WARNING):
             self.sync.sync_data(
-                options=['-a', '-H', '-X', '-A', '--one-file-system'],
+                options=[
+                    '--archive', '--hard-links', '--xattrs',
+                    '--acls', '--one-file-system'
+                ],
                 exclude=['exclude_me']
             )
             mock_command.assert_called_once_with(
                 [
-                    'rsync', '-a', '-H', '--one-file-system',
+                    'rsync', '--archive', '--hard-links', '--one-file-system',
                     '--exclude', '/exclude_me', 'source_dir', 'target_dir'
                 ]
             )
